devicesinlan - Mariano Muñoz

# NAME

devicesinlan: Scans all devices in your LAN. Then you can set an alias to your known devices in order to detect future strange devices in your net.

# SYNOPSIS

devicesinlan [--help] [--version] [--debug DEBUG] [ --interface | --add | --remove | --list | --load | --save | --reset ]

# DESCRIPTION

If you launch deviceslan without parameters a console wizard is launched.

Morever you can use one of this parameters.

--interface

Scans the net of the interface parameter and prints a list of the detected devices.

If a device is not known, it will be showed in red. Devices in green are trusted devices.

--add

Allows to add a known device from console.

--remove

Allows to remove a known device from console.

--list

Shows all known devices in database from console.

--load

Loads a list of known devices in xml format.

--save

Saves the known devices list to a xml file.

--debug

Gives debugging information when running DevicesInLAN. It's deactivated by default

The parameter can take this options: CRITICAL, ERROR, WARNING, INFO, DEBUG.

--reset

Removes all known devices.

Created with libmangenerator at 2018-11-19